@@ -2,10 +2,10 @@ import importlib.util
 import os
 import sys
 import time
-from inspect import getsource
+from inspect import getdoc, getsource
 from numbers import Integral, Number
 from pathlib import Path
-from tempfile import TemporaryDirectory
+from tempfile import NamedTemporaryFile, TemporaryDirectory
 from typing import Callable, Dict, List, Optional, Union
 from zipfile import ZipFile
 
@@ -13,8 +13,16 @@ from cognite.client import CogniteClient, utils
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import TimestampRange
 from cognite.client.exceptions import CogniteAPIError
+from pip._internal.req.constructors import install_req_from_line
 
-from cognite.experimental._constants import HANDLER_FILE_NAME, LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT, MAX_RETRIES
+from cognite.experimental._constants import (
+    HANDLER_FILE_NAME,
+    LIST_LIMIT_CEILING,
+    LIST_LIMIT_DEFAULT,
+    MAX_RETRIES,
+    REQUIREMENTS_FILE_NAME,
+    REQUIREMENTS_REG,
+)
 from cognite.experimental.data_classes import (
     Function,
     FunctionCall,
@@ -58,7 +66,7 @@ class FunctionsAPI(APIClient):
         index_url: Optional[str] = None,
         extra_index_urls: Optional[List[str]] = None,
     ) -> Function:
-        """`When creating a function, <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions>`_
+        """`When creating a function, <https://docs.cognite.com/api/playground/#operation/postFunctions>`_
         the source code can be specified in one of three ways:\n
         - Via the `folder` argument, which is the path to the folder where the source code is located. `function_path` must point to a python file in the folder within which a function named `handle` must be defined.\n
         - Via the `file_id` argument, which is the ID of a zip-file uploaded to the files API. `function_path` must point to a python file in the zipped folder within which a function named `handle` must be defined.\n
@@ -110,6 +118,24 @@ class FunctionsAPI(APIClient):
                 >>> from cognite.experimental import CogniteClient
                 >>> c = CogniteClient()
                 >>> function = c.functions.create(name="myfunction", function_handle=handle)
+
+            Create function with predefined function object named `handle` with dependencies::
+
+                >>> from cognite.experimental import CogniteClient
+                >>>
+                >>> def handle(client, data):
+                >>>     \"\"\"
+                >>>     [requirements]
+                >>>     numpy
+                >>>     [/requirements]
+                >>>     \"\"\"
+                >>>     ...
+                >>>
+                >>> c = CogniteClient()
+                >>> function = c.functions.create(name="myfunction", function_handle=handle)
+
+            .. note::
+                When using a predefined function object, you can list dependencies between the tags `[requirements]` and `[/requirements]` in the function's docstring. The dependencies will be parsed and validated in accordance with requirement format specified in `PEP 508 <https://peps.python.org/pep-0508/>`_.
         """
         self._assert_exactly_one_of_folder_or_file_id_or_function_handle(folder, file_id, function_handle)
 
@@ -165,7 +191,7 @@ class FunctionsAPI(APIClient):
         return Function._load(res.json()["items"][0], cognite_client=self._cognite_client)
 
     def delete(self, id: Union[int, List[int]] = None, external_id: Union[str, List[str]] = None) -> None:
-        """`Delete one or more functions. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-delete>`_
+        """`Delete one or more functions. <https://docs.cognite.com/api/playground/#operation/deleteFunctions>`_
 
         Args:
             id (Union[int, List[int]): Id or list of ids.
@@ -232,7 +258,7 @@ class FunctionsAPI(APIClient):
         return self._LIST_CLASS._load(res.json()["items"], cognite_client=self._cognite_client)
 
     def retrieve(self, id: Optional[int] = None, external_id: Optional[str] = None) -> Optional[Function]:
-        """`Retrieve a single function by id. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-context-functions-byids>`_
+        """`Retrieve a single function by id. <https://docs.cognite.com/api/playground/#operation/byIdsFunctions>`_
 
         Args:
             id (int, optional): ID
@@ -261,7 +287,7 @@ class FunctionsAPI(APIClient):
     def retrieve_multiple(
         self, ids: Optional[List[int]] = None, external_ids: Optional[List[str]] = None
     ) -> FunctionList:
-        """`Retrieve multiple functions by id. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-context-functions-byids>`_
+        """`Retrieve multiple functions by id. <https://docs.cognite.com/api/playground/#operation/byIdsFunctions>`_
 
         Args:
             ids (List[int], optional): IDs
@@ -295,7 +321,7 @@ class FunctionsAPI(APIClient):
         data: Optional[Dict] = None,
         wait: bool = True,
     ) -> FunctionCall:
-        """Call a function by its ID or external ID. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-function_name-call>`_.
+        """`Call a function by its ID or external ID. <https://docs.cognite.com/api/playground/#operation/postFunctionsCall>`_.
 
         Args:
             id (int, optional): ID
@@ -347,6 +373,19 @@ class FunctionsAPI(APIClient):
         return function_call
 
     def limits(self):
+        """`Get service limits. <https://docs.cognite.com/api/playground/#operation/functionsLimits>`_.
+
+        Returns:
+            FunctionsLimits: A function limits object.
+
+        Examples:
+
+            Call a function by id::
+
+                >>> from cognite.experimental import CogniteClient
+                >>> c = CogniteClient()
+                >>> limits = c.functions.limits()
+        """
         res = self._get("/functions/limits")
         return FunctionsLimits._load(res.json())
 
@@ -387,9 +426,16 @@ class FunctionsAPI(APIClient):
                 source = getsource(function_handle)
                 f.write(source)
 
+            # Read and validate requirements
+            req_path = get_requirements_handle(fn=function_handle)
+
             zip_path = os.path.join(tmpdir, "function.zip")
             zf = ZipFile(zip_path, "w")
             zf.write(handle_path, arcname=HANDLER_FILE_NAME)
+
+            # Zip requirements.txt
+            if req_path:
+                zf.write(req_path, arcname=REQUIREMENTS_FILE_NAME)
             zf.close()
 
             overwrite = True if external_id else False
@@ -532,6 +578,77 @@ def _assert_at_most_one_of_function_id_and_function_external_id(function_id, fun
     ), "Only function_id or function_external_id allowed when listing schedules."
 
 
+def extract_requirements_from_doc_string(docstr: str) -> Optional[List[str]]:
+    """Extracts a list of library requirements defined between [requirements] and [/requirements] in a functions docstring.
+
+    Args:
+        docstr (str): the docstring to extract requirements from
+
+    Returns:
+        (list[str] | None): returns a list of library records if requirements are defined in the docstring, else None
+    """
+    substr_start, substr_end = None, None
+
+    # Get index values for the start and end of the requirements list
+    for match in REQUIREMENTS_REG.finditer(docstr):
+        val = match.group()
+        if val == "[requirements]":
+            substr_start = match.end()
+        elif val == "[/requirements]":
+            substr_end = match.start()
+
+    if substr_start and substr_end:
+        # Return a list of requirement entries
+        return docstr[substr_start:substr_end].splitlines()[1:]
+    return None
+
+
+def validate_requirements(requirements: List[str]) -> str:
+    """Validates the requirement specifications
+
+    Args:
+        requirements (list[str]): list of requirement specifications
+
+    Raises:
+        ValueError: if validation of requirements fails
+
+    Returns:
+        str: output path of the requirements file
+    """
+    parsed_reqs: List[str] = []
+    for req in requirements:
+        parsed = install_req_from_line(req)
+        parsed_reqs.append(str(parsed))
+
+    tmp = NamedTemporaryFile()
+
+    # Write requirements to temporary file
+    with open(tmp.name, "w+") as f:
+        f.write("\n".join(parsed_reqs))
+        f.close()
+
+    return tmp.name
+
+
+def get_requirements_handle(fn: Callable) -> Optional[str]:
+    """Read requirements from a function docstring, and validate them
+
+    Args:
+        fn (Callable): the function to read requirements from
+
+    Returns:
+        str: output path of the requirements file, or None if no requirements are specified
+    """
+    docstr = getdoc(fn)
+
+    if docstr:
+        reqs = extract_requirements_from_doc_string(docstr)
+        if reqs:
+            return validate_requirements(reqs)
+
+    return None
+
+
 class FunctionCallsAPI(APIClient):
     _LIST_CLASS = FunctionCallList
 
@@ -545,7 +662,7 @@ class FunctionCallsAPI(APIClient):
         end_time: Optional[Dict[str, int]] = None,
         limit: Optional[int] = LIST_LIMIT_DEFAULT,
     ) -> FunctionCallList:
-        """List all calls associated with a specific function id. Either function_id or function_external_id must be specified.
+        """`List all calls associated with a specific function id. <https://docs.cognite.com/api/playground/#operation/listFunctionCalls>`_ Either function_id or function_external_id must be specified.
 
         Args:
             function_id (int, optional): ID of the function on which the calls were made.
@@ -586,7 +703,7 @@ class FunctionCallsAPI(APIClient):
     def retrieve(
         self, call_id: int, function_id: Optional[int] = None, function_external_id: Optional[str] = None
     ) -> Optional[FunctionCall]:
-        """`Retrieve a single function call by id. <https://docs.cognite.com/api/playground/#operation/byidsFunctionCalls>`_
+        """`Retrieve a single function call by id. <https://docs.cognite.com/api/playground/#operation/byIdsFunctionCalls>`_
 
         Args:
             call_id (int): ID of the call.
@@ -619,7 +736,7 @@ class FunctionCallsAPI(APIClient):
         return self._retrieve_multiple(wrap_ids=True, resource_path=resource_path, ids=call_id)
 
     def get_response(self, call_id: int, function_id: Optional[int] = None, function_external_id: Optional[str] = None):
-        """Retrieve the response from a function call.
+        """`Retrieve the response from a function call. <https://docs.cognite.com/api/playground/#operation/getFunctionCallResponse>`_
 
         Args:
             call_id (int): ID of the call.
@@ -655,7 +772,7 @@ class FunctionCallsAPI(APIClient):
     def get_logs(
         self, call_id: int, function_id: Optional[int] = None, function_external_id: Optional[str] = None
     ) -> FunctionCallLog:
-        """`Retrieve logs for function call. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-function_name-calls>`_
+        """`Retrieve logs for function call. <https://docs.cognite.com/api/playground/#operation/getFunctionCalls>`_
 
         Args:
             call_id (int): ID of the call.
@@ -694,7 +811,7 @@ class FunctionSchedulesAPI(APIClient):
     _LIST_CLASS = FunctionSchedulesList
 
     def retrieve(self, id: int) -> Optional[FunctionSchedule]:
-        """`Retrieve a single function schedule by id. <https://docs.cognite.com/api/playground/#operation/byidsFunctionSchedules>`_
+        """`Retrieve a single function schedule by id. <https://docs.cognite.com/api/playground/#operation/byIdsFunctionSchedules>`_
 
         Args:
             id (int): ID
@@ -779,7 +896,7 @@ class FunctionSchedulesAPI(APIClient):
         description: str = "",
         data: Optional[Dict] = None,
     ) -> FunctionSchedule:
-        """`Create a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-schedules>`_
+        """`Create a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/postFunctionSchedules>`_
 
         Args:
             name (str): Name of the schedule.
@@ -837,7 +954,7 @@ class FunctionSchedulesAPI(APIClient):
         return FunctionSchedule._load(res.json()["items"][0])
 
     def delete(self, id: int) -> None:
-        """`Delete a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-schedules-delete>`_
+        """`Delete a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/deleteFunctionSchedules>`_
 
         Args:
             id (int): Id of the schedule
@@ -859,8 +976,7 @@ class FunctionSchedulesAPI(APIClient):
         self._post(url, json=body)
 
     def get_input_data(self, id: int) -> Dict:
-        """
-        Retrieve the input data to the associated function.
+        """`Retrieve the input data to the associated function. <https://docs.cognite.com/api/playground/#operation/getFunctionScheduleInputData>`_
         Args:
             id (int): Id of the schedule
 
