@@ -1,6 +1,6 @@
 from cognite.experimental.data_classes.annotations import *
-from cognite.experimental.data_classes.annotations_v2 import *
 from cognite.experimental.data_classes.contextualization import *
 from cognite.experimental.data_classes.extractionpipelines import *
 from cognite.experimental.data_classes.functions import *
+from cognite.experimental.data_classes.legacy_annotations import *
 from cognite.experimental.data_classes.types import *
